import { I18nService, RouterService, StorageService } from '@lightweightform/core';
export interface Action {
    id?: string;
    text?: string;
    style?: string;
    icon?: string;
    options?: ActionOption[];
    callback: (value?: any) => void;
}
export interface ActionOption {
    value: any;
    text: string;
    isDisabled?: boolean | (() => boolean);
}
/**
 * Key used to set the label of the "actions" button when in "mobile" mode.
 */
export declare const I18N_TOP_BAR_ACTIONS_LABEL_KEY = "BS_TOP_BAR_ACTIONS_LABEL";
/**
 * Key used to translate the "retry validation" help message of fields.
 */
export declare const I18N_TOP_BAR_RETRY_VALIDATION_KEY = "BS_TOP_BAR_RETRY_VALIDATION";
/**
 * Key used to translate the text of the app's actions.
 */
export declare const I18N_ACTIONS_KEY = "BS_ACTIONS";
/**
 * Key used to translate the text of the options in app's actions.
 */
export declare const I18N_ACTIONS_OPTIONS_KEY = "BS_ACTIONS_OPTIONS";
export declare class TopBarComponent {
    protected _i18nService: I18nService;
    protected _routerService: RouterService;
    protected _storageService: StorageService;
    _actionsLabelText: string;
    _retryValidationText: string;
    private _actions;
    constructor(_i18nService: I18nService, _routerService: RouterService, _storageService: StorageService);
    readonly rootUrl: string;
    readonly actionsLabelText: any;
    readonly retryValidationText: string;
    readonly actions: Action[];
    readonly appHasPendingValidation: boolean;
    readonly shouldShowAppRecompute: boolean;
    recomputeAppStateProperties(): void;
    actionText(act: Action): string;
    actionOptionText(act: Action, option: any): string;
    isActionOptionDisabled(option: ActionOption): boolean;
}
